pub fn ChatApp(_: ChatAppProps) -> ElementExpand description
Shared application shell component used by both web and desktop apps. Renders the tab-lock screen, room prompt, or the main chat layout.
Props
For details, see the props struct definition.
signals:ChatAppSignalson_room_left:Option<EventHandler<()>>