pub fn handle_chat_event(event: CoordinatorEvent, signals: ChatAppSignals)Expand description
Handle a single coordinator event, updating the provided signals.
pub fn handle_chat_event(event: CoordinatorEvent, signals: ChatAppSignals)Handle a single coordinator event, updating the provided signals.